@@ -68,9 +68,13 @@ class WebDAVElement (object):
     allowed_attributes = None          # Allowed attribute names
     hidden             = False         # Don't list in PROPFIND with <allprop>
     protected          = False         # See RFC 3253 section 1.4.1
+    unregistered       = False         # Subclass of factory; doesn't register
 
-    def qname(self): return (self.namespace, self.name)
-    def sname(self): return "{%s}%s" % (self.namespace, self.name)
+    def qname(self):
+        return (self.namespace, self.name)
+
+    def sname(self):
+        return "{%s}%s" % (self.namespace, self.name)
 
     qname = classmethod(qname)
     sname = classmethod(sname)
@@ -94,7 +98,11 @@ class WebDAVElement (object):
         my_children = []
 
         for child in children:
-            if child is None: continue
+            if child is None:
+                continue
+
+            if isinstance(child, (str, unicode)):
+                child = PCDATAElement(child)
 
             assert isinstance(child, (WebDAVElement, PCDATAElement)), "Not an element: %r" % (child,)
 
@@ -106,7 +114,8 @@ class WebDAVElement (object):
                 else:
                     continue
 
-                if min is not None and min > 0: min -= 1
+                if min is not None and min > 0:
+                    min -= 1
                 if max is not None:
                     assert max > 0, "Too many children of type %s for %s" % (child.sname(), self.sname())
                     max -= 1
@@ -150,6 +159,9 @@ class WebDAVElement (object):
 
         self.attributes = my_attributes
 
+    def __str__(self):
+        return self.sname()
+
     def __repr__(self):
         if hasattr(self, "attributes") and hasattr(self, "children"):
             return "<%s %r: %r>" % (self.sname(), self.attributes, self.children)
@@ -223,7 +235,7 @@ class WebDAVElement (object):
         found = None
         for child in self.childrenOfType(child_type):
             if found:
-                raise ValueError("Multiple %s elements found in %s" % (child_type.sname(), self))
+                raise ValueError("Multiple %s elements found in %s" % (child_type.sname(), self.toxml()))
             found = child
         return found
 
@@ -351,10 +363,8 @@ class WebDAVTextElement (WebDAVElement):
     def fromString(clazz, string):
         if string is None:
             return clazz()
-        elif type(string) is str:
+        elif isinstance(string, (str, unicode)):
             return clazz(PCDATAElement(string))
-        elif type(string) is unicode:
-            return clazz(PCDATAElement(string.encode("utf-8")))
         else:
             return clazz(PCDATAElement(str(string)))
 
